package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Jan 26, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func ListCategories() []string
ListCategories returns unique categories
Art represents a piece of ASCII art
ByCategory returns all art in a category
List returns all art in the database
Random returns a random piece of art
Search searches art by name, category, or tags
Source Files
¶
Click to show internal directories.
Click to hide internal directories.